@@ -28,7 +28,13 @@ def describe_directory(directory, ignore_git=True):
                                 docstring = ""
                             else:
                                 docstring = ast.get_docstring(node)
-                            functions.update({node.name.replace(" ", "") + "(" + signature.replace(" ", "") + ")": docstring})
+                            if node.name == 'main':
+                                arguments = []
+                                for arg in node.args.args:
+                                    arguments.append(arg.arg)
+                                functions.update({'command_line_arguments': arguments})
+                            else:
+                                functions.update({node.name.replace(" ", "") + "(" + signature.replace(" ", "") + ")": docstring})
                         elif isinstance(node, ast.ClassDef):
                             if ast.get_docstring(node) is None:
                                 docstring = ""
